%define gobuild(o:) %{expand:
  # https://bugzilla.redhat.com/show_bug.cgi?id=995136#c12
  %global _dwz_low_mem_die_limit 0
  %ifnarch ppc64
  go build -buildmode pie -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-}%{?currentgoldflags} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags %{?__golang_extldflags}' -compressdwarf=false" -a -v -x %{?**};
  %else
  go build                -compiler gc -tags="rpm_crashtraceback ${BUILDTAGS:-}" -ldflags "${LDFLAGS:-}%{?currentgoldflags} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags %{?__golang_extldflags}' -compressdwarf=false" -a -v -x %{?**};
  %endif
}

# https://github.com/prometheus/node_exporter
%global goipath         github.com/prometheus/node_exporter
Version:                1.1.1

%global common_description %{expand:
Prometheus exporter for hardware and OS metrics exposed by *NIX kernels, written
in Go with pluggable metric collectors.}

%global golicenses      LICENSE NOTICE
%global godocs          docs examples CHANGELOG.md CODE_OF_CONDUCT.md\\\
                        CONTRIBUTING.md MAINTAINERS.md SECURITY.md README.md

Name:           golang-github-prometheus-node-exporter
Release:        1%{?dist}
Summary:        Exporter for machine metrics

# Upstream license specification: Apache-2.0
License:        ASL 2.0 and MIT
URL:            https://%{goipath}
Source0:        https://%{goipath}/archive/v%{version}/%{name}-%{version}.tar.gz
# git clone https://github.com/prometheus/node_exporter
# cd node_exporter
# git checkout v%%{version}
# git mod vendor
# tar -czvf vendor-%%{version}.tar.gz vendor/
Source10:       vendor-%{version}.tar.gz
Source1:        node_exporter.conf

# e.g. el6 has ppc64 arch without gcc-go, so EA tag is required
ExclusiveArch:  %{?go_arches:%{go_arches}}%{!?go_arches:%{ix86} x86_64 aarch64 %{arm}}
# If go_compiler is not set to 1, there is no virtual provide. Use golang instead.
BuildRequires:  %{?go_compiler:compiler(go-compiler)}%{!?go_compiler:golang}

%if (0%{?fedora} || 0%{?rhel} >= 8)
BuildRequires:  systemd-rpm-macros
%else
%{?systemd_requires}
BuildRequires:  systemd
%endif

%description
%{common_description}

%prep
%autosetup -p1 -a 10 -n node_exporter-%{version}

%build
export GO111MODULE=on
export GOFLAGS=-mod=vendor
export BUILDTAGS="netgo osusergo static_build"
%gobuild -o %{gobuilddir}/bin/node_exporter %{goipath}

%install
install -m 0755 -vd                     %{buildroot}%{_bindir}
install -m 0755 -vp %{gobuilddir}/bin/* %{buildroot}%{_bindir}/
install -m 0755 -vd                     %{buildroot}%{_sysusersdir}
install -m 0644 -vp %{SOURCE1}          %{buildroot}%{_sysusersdir}/
install -m 0755 -vd                                           %{buildroot}%{_sysconfdir}
install -m 0755 -vd                                           %{buildroot}%{_sysconfdir}/systemd
install -m 0755 -vd                                           %{buildroot}%{_sysconfdir}/systemd/system
install -m 0644 -vp examples/systemd/node_exporter.service    %{buildroot}%{_sysconfdir}/systemd/system/
install -m 0755 -vd                                           %{buildroot}%{_sysconfdir}
install -m 0755 -vd                                           %{buildroot}%{_sysconfdir}/sysconfig
install -m 0644 -vp examples/systemd/sysconfig.node_exporter  %{buildroot}%{_sysconfdir}/sysconfig/node_exporter

mkdir -p %{buildroot}%{_sharedstatedir}/node_exporter
mkdir -p %{buildroot}%{_sharedstatedir}/node_exporter/textfile_collector

%pre
%sysusers_create %{SOURCE1}

%post
%systemd_post node_exporter.service

%preun
%systemd_preun node_exporter.service

%postun
%systemd_postun_with_restart node_exporter.service

%files
%license LICENSE NOTICE
%doc docs examples CHANGELOG.md CODE_OF_CONDUCT.md CONTRIBUTING.md
%doc MAINTAINERS.md SECURITY.md README.md
%{_bindir}/*
%config(noreplace) %{_sysconfdir}/sysconfig/node_exporter
%config(noreplace) %{_sysconfdir}/systemd/system/node_exporter.service
%{_sysusersdir}/node_exporter.conf
%attr(0755,node_exporter,node_exporter) %{_sharedstatedir}/node_exporter

%changelog
* Wed Feb 17 2021 Robert-André Mauchin <zebob.m@gmail.com> - 1.1.1-1
- Initial package
